pub struct ToolCallResult {
pub content: Vec<ToolContentItem>,
pub is_error: bool,
}Expand description
Result of calling a tool.
Fields
content: Vec<ToolContentItem>The content items returned by the tool.
is_error: boolWhether the tool returned an error.
Implementations
Sourceimpl ToolCallResult
impl ToolCallResult
Sourcepub fn success(content: Vec<ToolContentItem>) -> Self
pub fn success(content: Vec<ToolContentItem>) -> Self
Creates a successful tool result with the given content.
Sourcepub fn text(text: impl Into<String>) -> Self
pub fn text(text: impl Into<String>) -> Self
Creates a successful tool result with a single text item.
Sourcepub fn first_text(&self) -> Option<&str>
pub fn first_text(&self) -> Option<&str>
Returns the first text content, if present.