pub struct ProgressReporter { /* private fields */ }Expand description
Progress reporter that wraps a notification sender with a progress token.
This is the concrete type stored in McpContext that handles sending progress notifications with the correct token.
Implementations
Sourceimpl ProgressReporter
impl ProgressReporter
Sourcepub fn new(sender: Arc<dyn NotificationSender>) -> Self
pub fn new(sender: Arc<dyn NotificationSender>) -> Self
Creates a new progress reporter with the given sender.